==> mingw-w64-ossia-score-3.4.1-1.src.tar.zst: ossia-score-3.4.1/src/lib/score/graphics/GraphicWidgets.hpp <==
#pragma once
#include <score/graphics/widgets/Constants.hpp>
#include <score/graphics/widgets/QGraphicsButton.hpp>
#include <score/graphics/widgets/QGraphicsCheckBox.hpp>
#include <score/graphics/widgets/QGraphicsCombo.hpp>
#include <score/graphics/widgets/QGraphicsEnum.hpp>
#include <score/graphics/widgets/QGraphicsHSVChooser.hpp>
#include <score/graphics/widgets/QGraphicsIntSlider.hpp>
#include <score/graphics/widgets/QGraphicsKnob.hpp>
#include <score/graphics/widgets/QGraphicsLineEdit.hpp>
#include <score/graphics/widgets/QGraphicsLogKnob.hpp>
#include <score/graphics/widgets/QGraphicsLogSlider.hpp>
#include <score/graphics/widgets/QGraphicsMultiSlider.hpp>
#include <score/graphics/widgets/QGraphicsNoteChooser.hpp>
#include <score/graphics/widgets/QGraphicsPixmapButton.hpp>
#include <score/graphics/widgets/QGraphicsPixmapEnum.hpp>
#include <score/graphics/widgets/QGraphicsPixmapToggle.hpp>
#include <score/graphics/widgets/QGraphicsRangeSlider.hpp>
#include <score/graphics/widgets/QGraphicsSelectablePixmapToggle.hpp>
#include <score/graphics/widgets/QGraphicsSlider.hpp>
#include <score/graphics/widgets/QGraphicsSliderBase.hpp>
#include <score/graphics/widgets/QGraphicsTextButton.hpp>
#include <score/graphics/widgets/QGraphicsTimeChooser.hpp>
#include <score/graphics/widgets/QGraphicsToggle.hpp>
#include <score/graphics/widgets/QGraphicsXYChooser.hpp>
#include <score/graphics/widgets/QGraphicsXYSpinbox.hpp>
#include <score/graphics/widgets/QGraphicsXYZChooser.hpp>
#include <score/graphics/widgets/QGraphicsXYZSpinbox.hpp>

==> mingw-w64-ossia-score-3.7.1-1.src.tar.zst: ossia-score-3.7.1/src/lib/score/graphics/GraphicWidgets.hpp <==
#pragma once
#include <score/graphics/widgets/Constants.hpp>
#include <score/graphics/widgets/QGraphicsButton.hpp>
#include <score/graphics/widgets/QGraphicsCheckBox.hpp>
#include <score/graphics/widgets/QGraphicsCombo.hpp>
#include <score/graphics/widgets/QGraphicsEnum.hpp>
#include <score/graphics/widgets/QGraphicsHSVChooser.hpp>
#include <score/graphics/widgets/QGraphicsIntSlider.hpp>
#include <score/graphics/widgets/QGraphicsKnob.hpp>
#include <score/graphics/widgets/QGraphicsLineEdit.hpp>
#include <score/graphics/widgets/QGraphicsLogKnob.hpp>
#include <score/graphics/widgets/QGraphicsLogSlider.hpp>
#include <score/graphics/widgets/QGraphicsMultiSlider.hpp>
#include <score/graphics/widgets/QGraphicsMultiSliderXY.hpp>
#include <score/graphics/widgets/QGraphicsPathGeneratorXY.hpp>
#include <score/graphics/widgets/QGraphicsNoteChooser.hpp>
#include <score/graphics/widgets/QGraphicsPixmapButton.hpp>
#include <score/graphics/widgets/QGraphicsPixmapEnum.hpp>
#include <score/graphics/widgets/QGraphicsPixmapToggle.hpp>
#include <score/graphics/widgets/QGraphicsRangeSlider.hpp>
#include <score/graphics/widgets/QGraphicsSelectablePixmapToggle.hpp>
#include <score/graphics/widgets/QGraphicsSlider.hpp>
#include <score/graphics/widgets/QGraphicsSliderBase.hpp>
#include <score/graphics/widgets/QGraphicsTextButton.hpp>
#include <score/graphics/widgets/QGraphicsTimeChooser.hpp>
#include <score/graphics/widgets/QGraphicsToggle.hpp>
#include <score/graphics/widgets/QGraphicsXYChooser.hpp>
#include <score/graphics/widgets/QGraphicsXYSpinbox.hpp>
#include <score/graphics/widgets/QGraphicsXYZChooser.hpp>
#include <score/graphics/widgets/QGraphicsXYZSpinbox.hpp>
